@@ -128,10 +128,11 @@ class BaseHandler(RequestHandler):
             arguments = self.request.arguments
             body_arguments = self.request.body
             if body_arguments:
-                # 获取body 对象并把byte转为str
                 body_arguments = body_arguments.decode()
-                # 将json字符串转换为json对象 并加入到 请求参数字典中
-                arguments.update(json.loads(body_arguments))
+                if content_type.find(
+                        "multipart/form-data") == -1 and content_type != "application/x-www-form-urlencoded":
+                    body_arguments = json.loads(body_arguments)
+                    arguments.update(body_arguments)
             # 获取处理方法的 参数签名
             signature = inspect.signature(handler_method)
             # parameterName 参数名称, parameter 参数对象
